pub enum IndexFormat {
Uint16,
Uint32,
}Expand description
The element width of the index buffer handed to setIndexBuffer.
The format must match the element type of the index data and the
PrimitiveState::strip_index_format when a strip topology is used.
Variants
Uint16
16-bit unsigned indices. Halves the index buffer, but a mesh with more than 65536 vertices would silently wrap.
Uint32
32-bit unsigned indices.