pub enum InputAction {
Pressed,
Held,
Released,
Idle,
}Expand description
Represents a high-level input action category.
Variants
Pressed
The key or button was pressed during this frame.
Held
The key or button is currently held down.
Released
The key or button was released during this frame.
Idle
The key or button is currently idle (not pressed).