pub enum OccluderKind {
Sphere,
Aabb,
}Expand description
Identifies the geometric shape of a ray-tracing Occluder.
Variants
Sphere
A sphere centered at center with radius stored in extent.x.
Aabb
An axis-aligned bounding box with min corner center and max corner
extent.