pub struct AssetCache { /* private fields */ }Expand description
A cache for storing loaded game assets, keyed by URL.
Implementations
Sourceimpl AssetCache
Implements cache query and management for AssetCache.
impl AssetCache
Implements cache query and management for AssetCache.
Sourcepub fn get_state(&self, url: &str) -> Option<AssetState>
pub fn get_state(&self, url: &str) -> Option<AssetState>
Sourcepub fn get_image(&self, url: &str) -> Option<HtmlImageElement>
pub fn get_image(&self, url: &str) -> Option<HtmlImageElement>
Sourcepub fn is_all_loaded(&self) -> bool
pub fn is_all_loaded(&self) -> bool
Returns true if all assets in the cache have finished loading.
Returns
bool- True if no assets are in theLoadingstate.
Sourcepub fn loaded_count(&self) -> usize
pub fn loaded_count(&self) -> usize
Returns the number of assets that have been successfully loaded.
Returns
usize- The count of loaded assets.
Sourceimpl AssetCache
impl AssetCache