EngineConfig

Struct EngineConfig 

pub struct EngineConfig { /* private fields */ }
The top-level engine configuration containing rendering and scheduler settings.

Passed to Engine::new to configure the engine instance.

Implementations

Source

impl EngineConfig

Implements construction helpers for EngineConfig.

pub fn create(render: RenderConfig) -> EngineConfig

Creates an engine configuration with the given render config and default scheduler.

Arguments
  • RenderConfig - The rendering configuration.
Returns
  • EngineConfig - The engine configuration.
pub fn with_scheduler(self, scheduler: SchedulerConfig) -> EngineConfig

Sets the scheduler configuration and returns the updated config.

Arguments
  • SchedulerConfig - The scheduler configuration.
Returns
  • EngineConfig - The updated engine configuration.
Source

impl EngineConfig

pub fn get_render(&self) -> RenderConfig

pub fn get_mut_render(&mut self) -> &mut RenderConfig

pub fn set_render(&mut self, val: RenderConfig) -> &mut Self

pub fn get_scheduler(&self) -> SchedulerConfig

pub fn get_mut_scheduler(&mut self) -> &mut SchedulerConfig

pub fn set_scheduler(&mut self, val: SchedulerConfig) -> &mut Self

Source

impl EngineConfig

pub fn new(render: RenderConfig) -> Self