pub struct GpuSamplerDescriptor { /* private fields */ }Expand description
A sampler descriptor for create_sampler.
Defaults produce a non-filtering clamp-to-edge sampler. Override fields after constructing to enable linear filtering, repeat addressing, or depth comparison.
Implementations
Sourceimpl GpuSamplerDescriptor
Default-construction helper for GpuSamplerDescriptor.
impl GpuSamplerDescriptor
Default-construction helper for GpuSamplerDescriptor.
Sourcepub fn default_sampler() -> Self
pub fn default_sampler() -> Self
Returns a descriptor with the most common defaults applied: nearest filtering and clamp-to-edge addressing on all axes.
Sourceimpl GpuSamplerDescriptor
impl GpuSamplerDescriptor
pub fn get_mag_filter(&self) -> &'static str
pub fn get_min_filter(&self) -> &'static str
pub fn get_mipmap_filter(&self) -> &'static str
pub fn get_address_mode_u(&self) -> &'static str
pub fn get_address_mode_v(&self) -> &'static str
pub fn get_address_mode_w(&self) -> &'static str
pub fn get_compare(&self) -> bool