LinearGradient

Struct LinearGradient 

pub struct LinearGradient { /* private fields */ }
A linear gradient defined by two endpoints and a list of color stops.

Used to create smooth color transitions along a straight line for fill or stroke operations on the canvas.

Implementations

Source

impl LinearGradient

Implements construction and canvas gradient creation for LinearGradient.

pub fn create( start: Vector2D, end: Vector2D, stops: Vec<(f64, String)>, ) -> LinearGradient

Creates a new linear gradient from two points and a list of color stops.

Arguments
  • Vector2D - The start point.
  • Vector2D - The end point.
  • Vec<(f64, String)> - The color stops as (position, color) pairs.
Returns
  • LinearGradient - The new gradient.
pub fn to_canvas_gradient( &self, context: &CanvasRenderingContext2d, ) -> Option<CanvasGradient>

Creates a CanvasGradient from this gradient definition on the given context.

Arguments
  • &CanvasRenderingContext2d - The canvas context.
Returns
  • Option<CanvasGradient> - The canvas gradient, or None if creation failed.
Source

impl LinearGradient

pub fn get_start(&self) -> Vector2D

pub fn get_mut_start(&mut self) -> &mut Vector2D

pub fn set_start(&mut self, val: Vector2D) -> &mut Self

pub fn get_end(&self) -> Vector2D

pub fn get_mut_end(&mut self) -> &mut Vector2D

pub fn set_end(&mut self, val: Vector2D) -> &mut Self

pub fn get_stops(&self) -> &Vec<(f64, String)>

pub fn get_mut_stops(&mut self) -> &mut Vec<(f64, String)>

pub fn set_stops(&mut self, val: Vec<(f64, String)>) -> &mut Self

Source

impl LinearGradient

pub fn new(start: Vector2D, end: Vector2D, stops: Vec<(f64, String)>) -> Self