Material

Struct Material 

pub struct Material { /* private fields */ }
A material describing how a surface responds to illumination.

Implementations

Source

impl Material

Implements factory constructors for Material.

pub fn lambert(albedo: Vector3D) -> Material

Creates a pure-Lambert material with the given albedo.

Arguments
  • Vector3D - The diffuse albedo color.
Returns
  • Material - A Lambertian material.
pub fn phong(albedo: Vector3D, specular: f64, shininess: f64) -> Material

Creates a Blinn-Phong material with the given albedo, specular strength, and specular exponent.

Arguments
  • Vector3D - The diffuse albedo color.
  • f64 - The specular intensity in the range 0.0..=1.0.
  • f64 - The Phong specular exponent.
Returns
  • Material - A Phong material.
pub fn emissive(color: Vector3D) -> Material

Creates a purely emissive material (light source with no shading).

Arguments
  • Vector3D - The self-illumination color.
Returns
  • Material - An emissive material.
Source

impl Material

pub fn get_kind(&self) -> MaterialKind

pub fn get_mut_kind(&mut self) -> &mut MaterialKind

pub fn set_kind(&mut self, val: MaterialKind) -> &mut Self

pub fn get_albedo(&self) -> Vector3D

pub fn get_mut_albedo(&mut self) -> &mut Vector3D

pub fn set_albedo(&mut self, val: Vector3D) -> &mut Self

pub fn get_specular(&self) -> f64

pub fn get_mut_specular(&mut self) -> &mut f64

pub fn set_specular(&mut self, val: f64) -> &mut Self

pub fn get_shininess(&self) -> f64

pub fn get_mut_shininess(&mut self) -> &mut f64

pub fn set_shininess(&mut self, val: f64) -> &mut Self

pub fn get_emissive(&self) -> Vector3D

pub fn get_mut_emissive(&mut self) -> &mut Vector3D

pub fn set_emissive(&mut self, val: Vector3D) -> &mut Self

Source

impl Material

pub fn new( kind: MaterialKind, albedo: Vector3D, specular: f64, shininess: f64, emissive: Vector3D, ) -> Self