pub struct ParticleConfig { /* private fields */ }Expand description
The static configuration of a particle emitter, describing how new particles are spawned and how they evolve over their lifetime.
Implementations
Sourceimpl ParticleConfig
impl ParticleConfig
pub fn get_emission_rate(&self) -> f64
pub fn get_mut_emission_rate(&mut self) -> &mut f64
pub fn get_max_particles(&self) -> usize
pub fn get_mut_max_particles(&mut self) -> &mut usize
pub fn get_lifetime_min(&self) -> f64
pub fn get_mut_lifetime_min(&mut self) -> &mut f64
pub fn get_lifetime_max(&self) -> f64
pub fn get_mut_lifetime_max(&mut self) -> &mut f64
pub fn get_speed_min(&self) -> f64
pub fn get_mut_speed_min(&mut self) -> &mut f64
pub fn get_speed_max(&self) -> f64
pub fn get_mut_speed_max(&mut self) -> &mut f64
pub fn get_angle(&self) -> f64
pub fn get_mut_angle(&mut self) -> &mut f64
pub fn set_angle(&mut self, val: f64) -> &mut Self
pub fn get_spread(&self) -> f64
pub fn get_mut_spread(&mut self) -> &mut f64
pub fn set_spread(&mut self, val: f64) -> &mut Self
pub fn get_gravity(&self) -> Vector2D
pub fn get_mut_gravity(&mut self) -> &mut Vector2D
pub fn set_gravity(&mut self, val: Vector2D) -> &mut Self
pub fn get_color_start(&self) -> Color
pub fn get_mut_color_start(&mut self) -> &mut Color
pub fn set_color_start(&mut self, val: Color) -> &mut Self
pub fn get_color_end(&self) -> Color
pub fn get_mut_color_end(&mut self) -> &mut Color
pub fn set_color_end(&mut self, val: Color) -> &mut Self
pub fn get_size_start(&self) -> f64
pub fn get_mut_size_start(&mut self) -> &mut f64
pub fn set_size_start(&mut self, val: f64) -> &mut Self
pub fn get_size_end(&self) -> f64
pub fn get_mut_size_end(&mut self) -> &mut f64
pub fn set_size_end(&mut self, val: f64) -> &mut Self