SphereCollider3D

Struct SphereCollider3D 

pub struct SphereCollider3D { /* private fields */ }
A 3D sphere collider wrapping a Sphere.

Implementations

Source

impl SphereCollider3D

Implements Collider3D trait and convenience methods for SphereCollider3D.

pub fn from_center(center: Vector3D, radius: f64) -> SphereCollider3D

Creates a new 3D sphere collider from a center point and radius.

Arguments
  • Vector3D - The center point.
  • f64 - The radius.
Returns
  • SphereCollider3D - The new collider.
pub fn collide_with_sphere( &self, other: &SphereCollider3D, ) -> Option<CollisionResult3D>

Tests collision with another sphere collider and returns the collision result.

Arguments
  • &SphereCollider3D - The other collider.
Returns
  • Option<CollisionResult3D> - The collision result, or None if no collision.
Source

impl SphereCollider3D

pub fn get_sphere(&self) -> Sphere

pub fn get_mut_sphere(&mut self) -> &mut Sphere

pub fn set_sphere(&mut self, val: Sphere) -> &mut Self

Source

impl SphereCollider3D

pub fn new(sphere: Sphere) -> Self