pub fn reflect_ray(ray: &Ray, hit: &Hit) -> RayExpand description
Builds a reflected ray bouncing off the hit surface.
Arguments
&Ray- The incoming ray.&Hit- The hit point with normal information.
Returns
Ray- A new ray originating at the hit point with the reflected direction,t_minreset toRAYTRACE_DEFAULT_T_MIN,t_maxset toRAYTRACE_DEFAULT_T_MAX, anddepthincremented by one.