pub struct LinearGradient { /* private fields */ }Expand description
A linear gradient defined by two endpoints and a list of color stops.
Used to create smooth color transitions along a straight line for fill or stroke operations on the canvas.
Implementations
Sourceimpl LinearGradient
Implements construction and canvas gradient creation for LinearGradient.
impl LinearGradient
Implements construction and canvas gradient creation for LinearGradient.
Sourcepub fn to_canvas_gradient(
&self,
context: &CanvasRenderingContext2d,
) -> Option<CanvasGradient>
pub fn to_canvas_gradient( &self, context: &CanvasRenderingContext2d, ) -> Option<CanvasGradient>
Sourceimpl LinearGradient
impl LinearGradient
pub fn get_start(&self) -> Vector2D
pub fn get_mut_start(&mut self) -> &mut Vector2D
pub fn set_start(&mut self, val: Vector2D) -> &mut Self
pub fn get_end(&self) -> Vector2D
pub fn get_mut_end(&mut self) -> &mut Vector2D
pub fn set_end(&mut self, val: Vector2D) -> &mut Self
pub fn get_stops(&self) -> &Vec<(f64, String)>
pub fn get_mut_stops(&mut self) -> &mut Vec<(f64, String)>
pub fn set_stops(&mut self, val: Vec<(f64, String)>) -> &mut Self