Occluder

Struct Occluder 

pub struct Occluder { /* private fields */ }
A ray-traceable geometric surface with an attached material.

Implementations

Source

impl Occluder

Implements factory constructors for Occluder.

pub fn sphere(center: Vector3D, radius: f64, material: Material) -> Occluder

Creates a spherical occluder centered at center with radius.

Arguments
  • Vector3D - The sphere center.
  • f64 - The sphere radius.
  • Material - The surface material.
Returns
  • Occluder - The new sphere occluder.
pub fn aabb(min: Vector3D, max: Vector3D, material: Material) -> Occluder

Creates an axis-aligned bounding-box occluder from min to max.

Arguments
  • Vector3D - The AABB minimum corner.
  • Vector3D - The AABB maximum corner.
  • Material - The surface material.
Returns
  • Occluder - The new AABB occluder.
pub fn occluder_points(&self) -> Vec<(Vector3D, f64)>

Returns a list of (center, radius) sphere tuples approximating this occluder, suitable for soft_shadow_factor.

For sphere occluders this returns (center, radius). For AABB occluders the bounding sphere is computed conservatively from the AABB extents.

Returns
  • Vec<(Vector3D, f64)> - One bounding sphere per occluder.
Source

impl Occluder

pub fn get_kind(&self) -> OccluderKind

pub fn get_mut_kind(&mut self) -> &mut OccluderKind

pub fn set_kind(&mut self, val: OccluderKind) -> &mut Self

pub fn get_center(&self) -> Vector3D

pub fn get_mut_center(&mut self) -> &mut Vector3D

pub fn set_center(&mut self, val: Vector3D) -> &mut Self

pub fn get_extent(&self) -> Vector3D

pub fn get_mut_extent(&mut self) -> &mut Vector3D

pub fn set_extent(&mut self, val: Vector3D) -> &mut Self

pub fn get_material(&self) -> &Material

pub fn get_mut_material(&mut self) -> &mut Material

pub fn set_material(&mut self, val: Material) -> &mut Self