Ray

Struct Ray 

pub struct Ray { /* private fields */ }
A 3D ray carrying the parameters needed for traversal and depth tracking.

Implementations

Source

impl Ray

Implements factory constructors and accessors for Ray and Occluder.

pub fn new(origin: Vector3D, direction: Vector3D) -> Ray

Creates a new ray starting at origin pointing in direction.

t_min and t_max default to [RAYTRACE_DEFAULT_T_MIN] and [RAYTRACE_DEFAULT_T_MAX]. depth defaults to 0.

Arguments
  • Vector3D - The ray origin.
  • Vector3D - The unit direction.
Returns
  • Ray - The new ray.
pub fn at(&self, t: f64) -> Vector3D

Computes the world-space point at distance t along this ray.

Arguments
  • f64 - The ray parameter.
Returns
  • Vector3D - origin + direction * t.
pub fn with_depth(&self, depth: u32) -> Ray

Returns a clone of this ray with depth replaced by depth.

Arguments
  • u32 - The new recursion depth.
Returns
  • Ray - The cloned ray with updated depth.
Source

impl Ray

pub fn get_origin(&self) -> Vector3D

pub fn get_mut_origin(&mut self) -> &mut Vector3D

pub fn set_origin(&mut self, val: Vector3D) -> &mut Self

pub fn get_direction(&self) -> Vector3D

pub fn get_mut_direction(&mut self) -> &mut Vector3D

pub fn set_direction(&mut self, val: Vector3D) -> &mut Self

pub fn get_t_min(&self) -> f64

pub fn get_mut_t_min(&mut self) -> &mut f64

pub fn set_t_min(&mut self, val: f64) -> &mut Self

pub fn get_t_max(&self) -> f64

pub fn get_mut_t_max(&mut self) -> &mut f64

pub fn set_t_max(&mut self, val: f64) -> &mut Self

pub fn get_depth(&self) -> u32

pub fn get_mut_depth(&mut self) -> &mut u32

pub fn set_depth(&mut self, val: u32) -> &mut Self