pub struct ShadowConfig { /* private fields */ }Expand description
Shadow rendering configuration for drop shadow effects on canvas primitives.
When applied, all subsequent fill, stroke, and draw operations will cast a shadow with the specified color, blur radius, and offset.
Implementations
Sourceimpl ShadowConfig
Implements construction methods for ShadowConfig.
impl ShadowConfig
Implements construction methods for ShadowConfig.
Sourcepub fn create() -> ShadowConfig
pub fn create() -> ShadowConfig
Creates a shadow configuration with default values.
Returns
ShadowConfig- The default shadow configuration.
Sourceimpl ShadowConfig
impl ShadowConfig
pub fn get_color(&self) -> String
pub fn get_mut_color(&mut self) -> &mut String
pub fn set_color(&mut self, val: String) -> &mut Self
pub fn get_blur(&self) -> f64
pub fn get_mut_blur(&mut self) -> &mut f64
pub fn set_blur(&mut self, val: f64) -> &mut Self
pub fn get_offset_x(&self) -> f64
pub fn get_mut_offset_x(&mut self) -> &mut f64
pub fn set_offset_x(&mut self, val: f64) -> &mut Self
pub fn get_offset_y(&self) -> f64
pub fn get_mut_offset_y(&mut self) -> &mut f64
pub fn set_offset_y(&mut self, val: f64) -> &mut Self